@@ -1,21 +1,22 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+# see license https://github.com/DerwenAI/pytextrank#license-and-copyright
 
 """
 Implements the base class for `TextRank` –
-with placeholder methods to be used by subclasses for algorithm extensions.
+with placeholder methods to be used by the subclasses for algorithm extensions.
 """
 
 from .util import groupby_apply, default_scrubber
 
 from collections import Counter, defaultdict, OrderedDict
 from dataclasses import dataclass
-from icecream import ic  # type: ignore # pylint: disable=W0611
-from spacy.tokens import Doc, Span, Token  # type: ignore
-import graphviz  # type: ignore
+from icecream import ic  # type: ignore # pylint: disable=E0401,W0611
+from spacy.tokens import Doc, Span, Token  # type: ignore # pylint: disable=E0401
+import graphviz  # type: ignore # pylint: disable=E0401
 import json
 import math
-import networkx as nx  # type: ignore
+import networkx as nx  # type: ignore # pylint: disable=E0401
 import pathlib
 import time
 import typing
@@ -210,7 +211,7 @@ the *stop words* dictionary
         ) -> Doc:
         """
 Set the extension attributes on a `spaCy` [`Doc`](https://spacy.io/api/doc)
-document to create a *pipeline component* for `TextRank` as
+document to create a *pipeline component* for `BaseTextRank` as
 a stateful component, invoked when the document gets processed.
 
 See: <https://spacy.io/usage/processing-pipelines#pipelines>
@@ -281,11 +282,16 @@ optional dictionary of `lemma: [pos]` items to define the *stop words*, where ea
         self.scrubber: typing.Callable = scrubber
         self.stopwords: typing.Dict[str, typing.List[str]] = stopwords
 
+        # internal data for BiasedTextRank
+        self.focus_tokens: typing.Set[str] = set()
+        self.node_bias = 1.0
+        self.default_bias = 1.0
+
         # effectively, performs the same work as the `reset()` method;
         # called explicitly here for the sake of type annotations
         self.elapsed_time: float = 0.0
         self.lemma_graph: nx.DiGraph = nx.DiGraph()
-        self.phrases: dict = defaultdict(list)
+        self.phrases: typing.List[Phrase] = []
         self.ranks: typing.Dict[Lemma, float] = {}
         self.seen_lemma: typing.Dict[Lemma, typing.Set[int]] = OrderedDict()
 
@@ -299,7 +305,7 @@ removing any pre-existing state.
         """
         self.elapsed_time = 0.0
         self.lemma_graph = nx.DiGraph()
-        self.phrases = defaultdict(list)
+        self.phrases = []
         self.ranks = {}
         self.seen_lemma = OrderedDict()
 
@@ -322,17 +328,16 @@ list of ranked phrases, in descending order
         self.lemma_graph = self._construct_graph()
 
         # to run the algorithm, we use the NetworkX implementation
-        # of PageRank (i.e., approximating eigenvalue centrality)
+        # for PageRank (i.e., based on eigenvector centrality)
         # to calculate a rank for each node in the lemma graph
         self.ranks = nx.pagerank(
             self.lemma_graph,
             personalization = self.get_personalization(),
-        )
+            )
 
         # agglomerate the lemmas ranked in the lemma graph into ranked
         # phrases, leveraging information from earlier stages of the
         # pipeline: noun chunks and named entities
-
         nc_phrases: typing.Dict[Span, float] = self._collect_phrases(self.doc.noun_chunks, self.ranks)
         ent_phrases: typing.Dict[Span, float] = self._collect_phrases(self.doc.ents, self.ranks)
         all_phrases: typing.Dict[Span, float] = { **nc_phrases, **ent_phrases }
@@ -497,7 +502,7 @@ Aggregate the rank metrics of the individual nodes (tokens) within
 each phrase.
 
     spans:
-spans of noun chuncks
+spans of noun chunks
 
     ranks:
 rank metrics corresponding to each node
